@@ -1,8 +1,14 @@
 # import the needed modules
+from __future__ import absolute_import
+from __future__ import print_function
 try:
 #  import sys
   import numpy
-  import pyfits
+  try:
+    from astropy.io import fits as pyfits
+  except:
+    import pyfits
+
   import wx
   import matplotlib
   import pipeline_product
@@ -81,7 +87,8 @@ try:
            #in case response is available we need to reduce fonts
            subplot.set_title(title, fontsize=7)
         try:
-            subplot.figure.tight_layout()
+            pass
+            #subplot.figure.tight_layout()
         except AttributeError:
             pass
 
@@ -117,7 +124,7 @@ try:
           bpm.readImage(fits_extension=2)
           img_bpm = ImageDisplay()
 
-	  img_obj.setLabels('Wavelength [nm]','Position Along Slit \n [arcsec]')
+          img_obj.setLabels('Wavelength [nm]','Position Along Slit \n [arcsec]')
           y_size, x_size = obj.image.shape
           #print 'x_size=',x_size , 'y_size=',y_size
           #print 'crval1=',obj.crval1,'crpix1=',obj.crpix1,'cdelt1=',obj.cdelt1 
@@ -125,7 +132,7 @@ try:
           img_obj.setXLinearWCSAxis(obj.crval1,obj.cdelt1,obj.crpix1)
           img_obj.setYLinearWCSAxis(obj.crval2,obj.cdelt2,obj.crpix2)
 
-	  #img_obj.setLimits((0,x_size),(0,y_size))
+          #img_obj.setLimits((0,x_size),(0,y_size))
           img_obj.display(subplot, title, self.paragraph(tooltip),obj.image,bpm.image)
           if self.response_found is True and self.rec_id[16:19] != "nod":
              #in case response is available we need to reduce fonts
@@ -144,10 +151,10 @@ try:
           img_bpm = ImageDisplay()
           error = obj.image[slice,:,:]
 
-	  #img_obj.setLabels('IFU slice [arcsec]','Position Along Slit \n [arcsec]')
-	  img_obj.setLabels('IFU slice [arcsec]','Position Along Slit \n [pixel]')
+          #img_obj.setLabels('IFU slice [arcsec]','Position Along Slit \n [arcsec]')
+          img_obj.setLabels('IFU slice [arcsec]','Position Along Slit \n [pixel]')
           y_size, x_size = image.shape
-          print 'x_size=',x_size , 'y_size=',y_size
+          print('x_size=',x_size , 'y_size=',y_size)
           #print 'crval1=',obj.crval1,'crpix1=',obj.crpix1,'cdelt1=',obj.cdelt1 
           #print 'crval2=',obj.crval2,'crpix2=',obj.crpix2,'cdelt2=',obj.cdelt2 
           
@@ -156,7 +163,7 @@ try:
           img_obj.setXLinearWCSAxis(-2,2,1)
           #img_obj.setYLinearWCSAxis(self.crval1,self.cdelt1,self.crpix1)
 
-	  #img_obj.setLimits((0,x_size),(0,y_size))
+          #img_obj.setLimits((0,x_size),(0,y_size))
           img_obj.display(subplot, title, self.paragraph(tooltip),image)
           if self.response_found is True and self.rec_id[16:19] != "nod":
              #in case response is available we need to reduce fonts
@@ -295,8 +302,8 @@ try:
         self.RN1 = "1514-1548 nm"
         self.OPTI5_NAME = hdulist[0].header['ESO INS OPTI5 NAME']
         if "JH" in self.OPTI5_NAME :
-   	  self.arm_nir_jh_found = True
-          print "Found NIR JH filter"
+          self.arm_nir_jh_found = True
+          print("Found NIR JH filter")
         else :
           self.SN2 = hdulist[0].header['ESO QC FLUX2 SN']
           self.RN2 = "2214-2243 nm"
@@ -350,12 +357,12 @@ try:
               #print rec_id, self.rec_id
               category = frame.category
               frames[category] = frame
-              print frame
+              print(frame)
       #Note that you have to take care that no other input to this py script
       #the same prefix as SCI_IFU, TELL_IFU, FLUX_IFU
  
       prefixes = [k.split('_')[0]+"_"+k.split('_')[1] for k in frames.keys()]
-      print  "prefixes=",prefixes
+      print("prefixes=",prefixes)
       if "SCI_IFU" in prefixes :
         prefix = "SCI_IFU_"
       elif "TELL_IFU" in prefixes:
@@ -370,12 +377,12 @@ try:
       arm=self.seq_arm
 
       if arm == "UVB":
- 	 self.arm_uvb_found = True
+         self.arm_uvb_found = True
       if arm == "VIS":
- 	 self.arm_vis_found = True
+         self.arm_vis_found = True
       if arm == "NIR":
- 	 self.arm_nir_found = True
-      print "prefix=",prefix
+         self.arm_nir_found = True
+      print("prefix=",prefix)
 # For any arm search a list of input frames
       key = prefix+"MERGE3D_DATA_OBJ_"+arm
       if key in frames :
@@ -426,7 +433,7 @@ try:
         self.flux_qual1D = PipelineProduct(hdulist)
         self.nima += 1
         #print "found FLUX_MERGED1D spectrum"
-	
+        
       key = prefix+"MERGE2D_"+arm
       if key in frames :
         self.spectrum2D_found = True
@@ -655,7 +662,7 @@ try:
 
       else : 
         self.subtext_nodata    = figure.add_subplot(1,1,1)
-        print "found no spectrum data"
+        print("found no spectrum data")
 
 
  
@@ -669,7 +676,7 @@ try:
     def plotProductsGraphics(self):
       if self.spectrum1D_found == True and self.spectrum2D_found == True: 
         #and self.lineguess_found == True 
-        title_pref = 'Standard-extracted and Merged Spectrum.'	      
+        title_pref = 'Standard-extracted and Merged Spectrum.'        
         title_flux_spectrum = 'Standard Extracted, Merged, and Flux Calibrated Spectrum.'
         tooltip_spectrum ="""\
                           Plot of the standard-extracted and merged spectrum of the object (blue line) as total flux (ADU) versus wavelength (nm). The +-1 sigma uncertainties are plotted as the light blue region encompassing the object spectrum (and bounded by the light grey spectra). Flagged pixels are marked with a dark-grey vertical bar stretching between the +- 1 sigma limits. Flagged bad pixels that are decoded as "bad pixels" are marked by a red vertical bar stretching between the +- 1 sigma limits. Note that this spectrum is not flux calibrated."""
@@ -693,18 +700,18 @@ try:
                               spectrum from the catalog is overplotted for
                               comparison purposes as a green line."""
 
-	if self.arm_uvb_found == True:
-      	  title_spectrum   = title_pref+' \n SN: %#.2f (%#s); %#.2f (%#s) '% (self.SN1,self.RN1,self.SN2,self.RN2)
+        if self.arm_uvb_found == True:
+          title_spectrum   = title_pref+' \n SN: %#.2f (%#s); %#.2f (%#s) '% (self.SN1,self.RN1,self.SN2,self.RN2)
 
-	if self.arm_vis_found == True:
-      	  title_spectrum   = title_pref+' \n SN: %#.2f (%#s); %#.2f (%#s); %#.2f (%#s) '% (self.SN1,self.RN1,self.SN2,self.RN2,self.SN3,self.RN3)
+        if self.arm_vis_found == True:
+          title_spectrum   = title_pref+' \n SN: %#.2f (%#s); %#.2f (%#s); %#.2f (%#s) '% (self.SN1,self.RN1,self.SN2,self.RN2,self.SN3,self.RN3)
 
-	if self.arm_nir_found == True and self.arm_nir_found == True:
-      	     title_spectrum   = title_pref+' \n SN: %#.2f (%#s); '% (self.SN1,self.RN1)
+        if self.arm_nir_found == True and self.arm_nir_found == True:
+             title_spectrum   = title_pref+' \n SN: %#.2f (%#s); '% (self.SN1,self.RN1)
         elif self.arm_nir_found == True :
-      	     title_spectrum   = title_pref+' \n SN: %#.2f (%#s); %#.2f (%#s); '% (self.SN1,self.RN1,self.SN2,self.RN2)
-	   
-	   
+             title_spectrum   = title_pref+' \n SN: %#.2f (%#s); %#.2f (%#s); '% (self.SN1,self.RN1,self.SN2,self.RN2)
+           
+           
         #Spectrum plot
 
         self.plotSpectrum(self.spectrum1D,self.error1D,self.qual1D,self.decode_bp,self.subplot_spectrum,title_spectrum,tooltip_spectrum)
@@ -780,9 +787,11 @@ try:
                           Traces of the IFU object central position
         observed by slicer number 1,2,3 are displayed respectively in
         colors blue, green, red. If the cube has been perfectly 
-        reconstructed the three traces should overlap.
+        reconstructed the three traces should overlap. Traces are well
+        defined only for point-like and high SNR objects. Low SNR pr
+        extended objects may present a not aggregated point distribution.
                                       """
-        plane_id=numpy.floor(self.NAXIS3/2+0.5)
+        plane_id=int(numpy.floor(self.NAXIS3/2+0.5))
         self.setDisplayCubeSlice(plane_id)
 
         self.plotTableScatter(self.traces_ifu_slices,'WAVELENGTH','POS_1', 'Wavelength [nm]','Slit position [pix]',self.subplot_traces_ifu_slices,title_traces_ifu_slices,tooltip_traces_ifu_slices)
@@ -809,7 +818,7 @@ try:
                                  fontsize=18, ha='left', va='center', alpha=1.0)
         self.subtext_nodata.tooltip="""\
                                     Merged spectrum not found in the products"""
-        print "found no spectrum data"
+        print("found no spectrum data")
  
   
     # This function specifies which are the parameters that should be presented
@@ -819,7 +828,7 @@ try:
     # The descriptions are used to show a tooltip. They should match one to one
     # with the parameter list 
     # Note also that parameters have to be prefixed by the 'recipe name:'
-   	
+        
     def setInteractiveParameters(self):
       paramList = list()
 
@@ -828,15 +837,15 @@ try:
 
       self.par.setGeneralObjectParameters(paramList,rec_id)
 
-      print rec_id
+      print(rec_id)
       if ("stare" in rec_id) or ("nod" in rec_id) :
-         print "entered"
+         print("entered")
          self.par.setStackParameters(paramList,rec_id)
       if self.rec_id != "xsh_scired_ifu_stare" :
          self.par.setCrhSingleParameters(paramList,rec_id)
 
       if rec_id[16:21] == "stare" :
-         print "background"
+         print("background")
          self.par.setBackgroundParameters(paramList,rec_id)
 
       if self.rec_id != "xsh_scired_ifu_stare" :
@@ -857,6 +866,6 @@ This is an interactive window which help asses the quality of the execution of a
 
 except ImportError:
   import_sucess = 'false'
-  print "Error importing modules pyfits, wx, matplotlib, numpy"
+  print("Error importing modules pyfits, wx, matplotlib, numpy")
   raise
 
